Crate schnorr_orchard

Crate schnorr_orchard 

Structs

Address
A shielded payment address.
Diversifier
A diversifier that can be used to derive a specific Address from a FullViewingKey or IncomingViewingKey.
IncomingViewingKey
A key that provides the capability to detect and decrypt incoming notes from the block chain, without being able to spend the notes or detect when they are spent.
Message
Message to be signed.
Personalization
Personalization string of the signing scheme.

Functions

sign
Produce a Signature over message.
verify
Verify a Signature produced with an IncomingViewingKey, using its associated Address.

Type Aliases

Signature
Signature produced with sign.