Structs
- Address
- A shielded payment address.
- Diversifier
- A diversifier that can be used to derive a specific
Addressfrom aFullViewingKeyorIncomingViewingKey. - Incoming
Viewing Key - A key that provides the capability to detect and decrypt incoming notes from the block chain, without being able to spend the notes or detect when they are spent.
- Message
- Message to be signed.
- Personalization
- Personalization string of the signing scheme.
Functions
- sign
- Produce a
Signatureovermessage. - verify
- Verify a
Signatureproduced with anIncomingViewingKey, using its associatedAddress.